# encoding: utf-8

"""
ocean_sar: utilities to handle SAR data.

Copyright (C) 2014-2018 OceanDataLab

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import os
from setuptools import setup
try:
    import subprocess32 as subprocess
except ImportError:
    import subprocess

package_dir = os.path.dirname(__file__)
version_path = os.path.join(package_dir, 'VERSION.txt')

major_version = '0.0'
if os.path.exists('.git') and os.path.isdir('.git'):
    commits = subprocess.check_output([ '/usr/bin/git'
                                      , 'rev-list'
                                      , 'HEAD'
                                      , '--count']).decode('utf-8').strip()
    with open(version_path, 'w') as f:
        f.write('{}.{}\n'.format(major_version, commits))

with open(version_path, 'r') as f:
    version = f.read()

setup(
    zip_safe=False,
    name='sar4ocean',
    version=version,
    author='Gilles Guitton <gilles.guitton@oceandatalab.com>',
    author_email='gilles.guitton@oceandatalab.com',
    packages=[ 'sar'
             , 'sar.data'
             , 'sar.processing'
             , 'sar.render'
             , 'sar.transform'
             , 'sar.utils'
             , 'sar.utils.datapath'
             ],
    scripts=[
        'bin/s1-path',
        'bin/s1-datahub',
        'bin/sar_crossspectra_png.py',
        'bin/sar_dn_png.py',
        'bin/sar_roughness_png.py',
        'bin/sar-xspec'
    ],
    license='AGPLv3',
    description='Utilities to handle SAR data.',
    long_description=open('README.txt').read(),
    install_requires=[ 'numpy'
                     , 'scipy'
                     , 'shapely'
                     , 'matplotlib'
                     , 'cerbere'
    ],
    package_data={ 'sar': [ 'share/logos/*.*'
                          , 'render/palette/*.*']
    },
)
